@@ -1,5 +1,5 @@
 package Music::Intervals::Ratio;
-$Music::Intervals::Ratio::VERSION = '0.0401';
+$Music::Intervals::Ratio::VERSION = '0.0402';
 BEGIN {
   $Music::Intervals::Ratio::AUTHORITY = 'cpan:GENE';
 }
@@ -241,6 +241,7 @@ our $ratio = {
     '90/77' => q|swetismic subminor third|,
     '91/59' => q|15/4-tone|,
     '91/64' => q|91st harmonic|,
+    '91/90' => q|Superleap|,
     '93/64' => q|93rd harmonic|,
     '95/64' => q|95th harmonic|,
     '96/77' => q|undecimal perde segah, keenanismic major third|,
@@ -266,7 +267,7 @@ our $ratio = {
     '115/64' => q|115th harmonic|,
     '117/64' => q|117th harmonic|,
     '119/64' => q|119th harmonic|,
-    '121/120' => q|undecimal seconds comma|,
+    '121/120' => q|undecimal seconds comma, Biyatisma|,
     '121/64' => q|121st harmonic|,
     '123/64' => q|123rd harmonic|,
     '125/108' => q|semi-augmented whole tone|,
@@ -290,6 +291,7 @@ our $ratio = {
     '160/81' => q|octave minus syntonic comma|,
     '161/93' => q|19/4-tone|,
     '162/149' => q|Persian neutral second|,
+    '176/175' => q|Valinorsma|,
     '192/125' => q|classic diminished sixth|,
     '196/169' => q|consonant interval (Avicenna)|,
     '216/125' => q|semi-augmented sixth|,
@@ -321,6 +323,7 @@ our $ratio = {
     '385/384' => q|undecimal kleisma|,
     '400/243' => q|grave major sixth|,
     '405/256' => q|wide augmented fifth|,
+    '441/440' => q|Werckisma|,
     '512/343' => q|3 septatones or septatonic fifth|,
     '512/375' => q|double diminished fifth|,
     '512/405' => q|narrow diminished fourth|,
@@ -331,6 +334,7 @@ our $ratio = {
     '625/567' => q|BP great semitone|,
     '648/625' => q|major diesis|,
     '675/512' => q|wide augmented third|,
+    '676/675' => q|Parizeksma|,
     '687/500' => q|11/4-tone|,
     '729/400' => q|acute minor seventh|,
     '729/512' => q|high Pythagorean tritone|,
@@ -369,6 +373,7 @@ our $ratio = {
     '3125/3087' => q|major BP diesis|,
     '3375/2048' => q|double augmented fifth|,
     '4000/3969' => q|septimal semicomma|,
+    '4000/3993' => q|Wizardharry|,
     '4096/2187' => q|Pythagorean diminished octave|,
     '4096/2401' => q|4 septatones or septatonic major sixth|,
     '4096/3375' => q|double diminished fourth|,
@@ -378,6 +383,7 @@ our $ratio = {
     '5120/5103' => q|Beta 5|,
     '5625/4096' => q|double augmented third|,
     '6144/3125' => q|octave - small diesis|,
+    '6144/6125' => q|Porwell|,
     '6561/4096' => q|Pythagorean augmented fifth, Pythagorean "schismatic" sixth|,
     '6561/5120' => q|acute major third|,
     '6561/6125' => q|BP major link|,
@@ -409,9 +415,11 @@ our $ratio = {
     '59049/57344' => q|Harrison's comma|,
     '65536/32805' => q|octave - schisma|,
     '65536/59049' => q|Pythagorean diminished third|,
+    '65536/65219' => q|Orgonisma|,
     '78732/78125' => q|medium semicomma|,
     '83349/78125' => q|BP minor link|,
     '177147/131072' => q|Pythagorean augmented third|,
+    '250047/250000' => q|Landscape Comma|,
     '262144/177147' => q|Pythagorean diminished sixth|,
     '390625/196608' => q|octave - Würschmidt's comma|,
     '393216/390625' => q|Würschmidt's comma|,
@@ -464,7 +472,7 @@ Music::Intervals::Ratio
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 AUTHOR
 
