@@ -1,5 +1,5 @@
 package Music::Intervals::Ratios;
-$Music::Intervals::Ratios::VERSION = '0.0401';
+$Music::Intervals::Ratios::VERSION = '0.0402';
 BEGIN {
   $Music::Intervals::Ratios::AUTHORITY = 'cpan:GENE';
 }
@@ -947,6 +947,10 @@ our $ratio = {
         ratio => '91/64',
         name => q|91st harmonic|,
     },
+    supl => {
+        ratio => '91/90',
+        name => q|Superleap|,
+    },
     '93h' => {
         ratio => '93/64',
         name => q|93rd harmonic|,
@@ -1049,7 +1053,7 @@ our $ratio = {
     },
     u2c => {
         ratio => '121/120',
-        name => q|undecimal seconds comma|,
+        name => q|undecimal seconds comma, Biyatisma|,
     },
     '121h' => {
         ratio => '121/64',
@@ -1143,6 +1147,10 @@ our $ratio = {
         ratio => '162/149',
         name => q|Persian neutral second|,
     },
+    vali => {
+        ratio => '176/175',
+        name => q|Valinorsma|,
+    },
     cd6 => {
         ratio => '192/125',
         name => q|classic diminished sixth|,
@@ -1267,6 +1275,10 @@ our $ratio = {
         ratio => '405/256',
         name => q|wide augmented fifth|,
     },
+    werc => {
+        ratio => '441/440',
+        name => q|Werckisma|,
+    },
     st5 => {
         ratio => '512/343',
         name => q|3 septatones or septatonic fifth|,
@@ -1307,6 +1319,10 @@ our $ratio = {
         ratio => '675/512',
         name => q|wide augmented third|,
     },
+    pari => {
+        ratio => '676/675',
+        name => q|Parizeksma|,
+    },
     '114t' => {
         ratio => '687/500',
         name => q|11/4-tone|,
@@ -1457,7 +1473,11 @@ our $ratio = {
     },
     ssc => {
         ratio => '4000/3969',
-        name => q|septimal semicomma|,
+        name => q|septimal semicomma, Octagar|,
+    },
+    wiz => {
+        ratio => '4000/3993',
+        name => q|Wizardharry|,
     },
     pdo => {
         ratio => '4096/2187',
@@ -1495,6 +1515,10 @@ our $ratio = {
         ratio => '6144/3125',
         name => q|octave - small diesis|,
     },
+    por => {
+        ratio => '6144/6125',
+        name => q|Porwell|,
+    },
     pa5 => {
         ratio => '6561/4096',
         name => q|Pythagorean augmented fifth, Pythagorean "schismatic" sixth|,
@@ -1619,6 +1643,10 @@ our $ratio = {
         ratio => '65536/59049',
         name => q|Pythagorean diminished third|,
     },
+    orgo => {
+        ratio => '65536/65219',
+        name => q|Orgonisma|,
+    },
     msc => {
         ratio => '78732/78125',
         name => q|medium semicomma|,
@@ -1631,6 +1659,10 @@ our $ratio = {
         ratio => '177147/131072',
         name => q|Pythagorean augmented third|,
     },
+    land => {
+        ratio => '250047/250000',
+        name => q|Landscape Comma|,
+    },
     pd6 => {
         ratio => '262144/177147',
         name => q|Pythagorean diminished sixth|,
@@ -1791,7 +1823,7 @@ Music::Intervals::Ratios
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 AUTHOR
 
